==> zio-aws-kafka_2.13-5.17.104.3-sources.jar: zio/aws/kafka/model/DescribeClusterOperationRequest.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DescribeClusterOperationRequest(
    clusterOperationArn: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.DescribeClusterOperationRequest = {
    import DescribeClusterOperationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.DescribeClusterOperationRequest
      .builder()
      .clusterOperationArn(
        __string.unwrap(clusterOperationArn): java.lang.String
      )
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.DescribeClusterOperationRequest.ReadOnly =
    zio.aws.kafka.model.DescribeClusterOperationRequest.wrap(buildAwsValue())
}
object DescribeClusterOperationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.DescribeClusterOperationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.DescribeClusterOperationRequest =
      zio.aws.kafka.model.DescribeClusterOperationRequest(clusterOperationArn)
    def clusterOperationArn: __string
    def getClusterOperationArn: ZIO[Any, Nothing, __string] =
      ZIO.succeed(clusterOperationArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.DescribeClusterOperationRequest
  ) extends zio.aws.kafka.model.DescribeClusterOperationRequest.ReadOnly {
    override val clusterOperationArn: __string =
      zio.aws.kafka.model.primitives.__string(impl.clusterOperationArn())
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.DescribeClusterOperationRequest
  ): zio.aws.kafka.model.DescribeClusterOperationRequest.ReadOnly = new Wrapper(
    impl
  )
}

==> zio-aws-kafka_2.13-5.17.211.1-sources.jar: zio/aws/kafka/model/DescribeClusterOperationRequest.scala <==
package zio.aws.kafka.model
import zio.ZIO
import zio.aws.kafka.model.primitives.__string
import zio.aws.core.BuilderHelper
import scala.jdk.CollectionConverters._
final case class DescribeClusterOperationRequest(
    clusterOperationArn: __string
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.kafka.model.DescribeClusterOperationRequest = {
    import DescribeClusterOperationRequest.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.kafka.model.DescribeClusterOperationRequest
      .builder()
      .clusterOperationArn(clusterOperationArn: java.lang.String)
      .build()
  }
  def asReadOnly: zio.aws.kafka.model.DescribeClusterOperationRequest.ReadOnly =
    zio.aws.kafka.model.DescribeClusterOperationRequest.wrap(buildAwsValue())
}
object DescribeClusterOperationRequest {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.kafka.model.DescribeClusterOperationRequest
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.kafka.model.DescribeClusterOperationRequest =
      zio.aws.kafka.model.DescribeClusterOperationRequest(clusterOperationArn)
    def clusterOperationArn: __string
    def getClusterOperationArn: ZIO[Any, Nothing, __string] =
      ZIO.succeed(clusterOperationArn)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.kafka.model.DescribeClusterOperationRequest
  ) extends zio.aws.kafka.model.DescribeClusterOperationRequest.ReadOnly {
    override val clusterOperationArn: __string =
      impl.clusterOperationArn(): __string
  }
  def wrap(
      impl: software.amazon.awssdk.services.kafka.model.DescribeClusterOperationRequest
  ): zio.aws.kafka.model.DescribeClusterOperationRequest.ReadOnly = new Wrapper(
    impl
  )
}
